@@ -1,5 +1,5 @@
 #define PCI_CONFIG_H
-#define PCI_ARCH_ARMV5TEL
+#define PCI_ARCH_ARMV7L
 #define PCI_OS_LINUX
 #define PCI_HAVE_PM_LINUX_SYSFS
 #define PCI_HAVE_PM_LINUX_PROC
@@ -13,4 +13,5 @@
 #define PCI_PATH_IDS_DIR "/usr/share/hwdata"
 #define PCI_USE_DNS
 #define PCI_ID_DOMAIN "pci.id.ucw.cz"
-#define PCILIB_VERSION "3.1.9"
+#define PCI_USE_LIBKMOD
+#define PCILIB_VERSION "3.2.0"
